@@ -2561,7 +2561,7 @@ the utilities listed below.
 
 =head1 AUTHOR
 
-Zane C. Bowers, C<< <vvelox at vvelox.net> >>
+Zane C. Bowers-Hadley, C<< <vvelox at vvelox.net> >>
 
 =head1 BUGS
 
@@ -2596,15 +2596,17 @@ L<http://cpanratings.perl.org/d/ZConf>
 
 L<http://search.cpan.org/dist/ZConf>
 
-=back
+=item * Subversion Repository
 
+L<http://eesdp.org/svnweb/index.cgi/pubsvn/browse/Perl/ZConf>
+
+=back
 
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 Zane C. Bowers, all rights reserved.
+Copyright 2011 Zane C. Bowers-Hadley, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
